@@ -17,6 +17,7 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "sddmauthhelper.h"
+#include "src/config.h"
 
 #include <unistd.h>
 
@@ -38,6 +39,12 @@
 
 static QSharedPointer<KConfig> openConfig(const QString &filePath)
 {
+    // if the sddm.conf.d folder doesn't exist we fail to set the right permissions for kde_settings.conf
+    QFileInfo fileLocation(filePath);
+    QDir dir(fileLocation.absolutePath());
+    if (!dir.exists()) {
+        QDir().mkpath(dir.path());
+    }
     QFile file(filePath);
     if(!file.exists()) {
         // If we are creating the config file, ensure it is world-readable: if
@@ -47,6 +54,11 @@ static QSharedPointer<KConfig> openConfig(const QString &filePath)
         file.close();
         file.setPermissions(QFile::ReadOwner | QFile::WriteOwner | QFile::ReadGroup | QFile::ReadOther);
     }
+    // in case the file has already been created with wrong permissions
+    else if (!(file.permissions() & QFile::ReadOwner & QFile::WriteOwner & QFile::ReadGroup & QFile::ReadOther)) {
+        file.setPermissions(QFile::ReadOwner | QFile::WriteOwner | QFile::ReadGroup | QFile::ReadOther);
+    }
+
     return QSharedPointer<KConfig>(new KConfig(file.fileName(), KConfig::SimpleConfig));
 }
 
@@ -212,8 +224,8 @@ ActionReply SddmAuthHelper::reset(const QVariantMap &args)
 ActionReply SddmAuthHelper::save(const QVariantMap &args)
 {
     ActionReply reply = ActionReply::HelperErrorReply();
-    QSharedPointer<KConfig> sddmConfig = openConfig(args[QStringLiteral("kde_settings.conf")].toString());
-    QSharedPointer<KConfig> sddmOldConfig = openConfig(args[QStringLiteral("sddm.conf")].toString());
+    QSharedPointer<KConfig> sddmConfig = openConfig(QString {QLatin1String(SDDM_CONFIG_DIR "/") + QStringLiteral("kde_settings.conf")});
+    QSharedPointer<KConfig> sddmOldConfig = openConfig(QLatin1String(SDDM_CONFIG_FILE));
     QSharedPointer<KConfig> themeConfig;
     QString themeConfigFile = args[QStringLiteral("theme.conf.user")].toString();
 
